==> tdm_2.1.1.tar.gz: tdm/R/all.Amidihinfusionms.R <==
all.Amidihinfusionms<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihinfusionMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),DL=c(0),tinf=c(0),R=c(0),ts=c(0),c=c(0))
     AmidihinfusionMSpar<-edit(AmidihinfusionMSpar)
     AmidihinfusionMSpar<-ymscheck(AmidihinfusionMSpar)
     cat("\n")
     Amidihinfusion.ms(length(AmidihinfusionMSpar$subject),AmidihinfusionMSpar$c,AmidihinfusionMSpar$ts,AmidihinfusionMSpar$ht,AmidihinfusionMSpar$age,AmidihinfusionMSpar$smoke,AmidihinfusionMSpar$Gender,AmidihinfusionMSpar$CHF,AmidihinfusionMSpar$DL,AmidihinfusionMSpar$R,AmidihinfusionMSpar$tinf)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-Theinfusioncpr(0.8,AmidihinfusionMSpar$DL,AmidihinfusionMSpar$R,AmidihinfusionMSpar$ts,AmidihinfusionMSpar$tinf)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")     
     coutput1<-coutput
     show(coutput)
     C<-0.8*AmidihinfusionMSpar$R/(samplesStats("cl"))
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)") 
     coutput2<-coutput
     show(coutput)
     cat("\n")   
     cal.again()            
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Amidihinfusionms.R <==
all.Amidihinfusionms<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihinfusionMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),DL=c(0),tinf=c(0),R=c(0),ts=c(0),c=c(0))
     AmidihinfusionMSpar<-edit(AmidihinfusionMSpar)
##     AmidihinfusionMSpar<-ymscheck(AmidihinfusionMSpar)
     cat("\n")
     Amidihinfusion.ms(length(AmidihinfusionMSpar$subject),AmidihinfusionMSpar$c,AmidihinfusionMSpar$ts,AmidihinfusionMSpar$ht,AmidihinfusionMSpar$age,AmidihinfusionMSpar$smoke,AmidihinfusionMSpar$Gender,AmidihinfusionMSpar$CHF,AmidihinfusionMSpar$DL,AmidihinfusionMSpar$R,AmidihinfusionMSpar$tinf)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-Theinfusioncpr(0.8,AmidihinfusionMSpar$DL,AmidihinfusionMSpar$R,AmidihinfusionMSpar$ts,AmidihinfusionMSpar$tinf)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")     
     coutput1<-coutput
     show(coutput)
     C<-0.8*AmidihinfusionMSpar$R/(samplesStats("cl"))
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)") 
     coutput2<-coutput
     show(coutput)
     cat("\n")   
     cal.again()            
}
